class DecalConfigClientWindow extends UWindowDialogClientWindow
		config(DecalStayPlus);

var() config bool bExtendedDecals;
var() config bool bPermanentDecals;
var() config int TimeMultiplier;
var() config int MaxDecals;

var localized string DecalMultiplierText;
var localized string DecalMultiplierHelp;

var UWindowSmallButton CloseButton, ZapButton;
var UWindowSmallCloseButton CancelButton;
var UWindowCheckbox EnabledCheckbox;
var UWindowCheckbox PermanentCheckbox;
var UWindowEditControl DecalCountBox;
var UWindowEditControl MaxDecalsBox;
var  UWindowEditControl DecalLength;
var UMenuLabelControl MultiplierLabel;

var int DecalCount;

function Created()
{
	UpdateCnt();
	Super.Created();

	// Enabled box
	EnabledCheckBox = UWindowCheckbox( CreateControl( class'UWindowCheckbox', 10, 10, 180, 1 ) );
	EnabledCheckBox.SetText("Enable DecalStayPlus:");
	EnabledCheckBox.SetFont(F_Normal);
	EnabledCheckBox.bChecked = bExtendedDecals;
	EnabledCheckBox.NotifyWindow = Self; // doesn't seem to work otherwise.

	// Permanent box
	PermanentCheckBox = UWindowCheckbox( CreateControl( class'UWindowCheckbox', 10, 25, 180, 1 ) );
	PermanentCheckBox.SetText("Make Decals Permanent:");
	PermanentCheckBox.SetFont(F_Normal);
	PermanentCheckBox.bChecked = bPermanentDecals;
	PermanentCheckBox.NotifyWindow = Self;
	if (!bExtendedDecals) PermanentCheckBox.bDisabled = true;

	// DecalLength
	DecalLength = UWindowEditControl(CreateWindow(class'UWindowEditControl', 10, 65, 180, 150));
	DecalLength.Align = TA_Left;
	DecalLength.SetFont(F_Bold);
	DecalLength.SetValue(Right(string(TimeMultiplier), 16));
	if (!bExtendedDecals) DecalLength.SetText("DecalStayPlus Disabled");
		else if (bPermanentDecals) DecalLength.SetText("Decals stay forever");
			else DecalLength.SetText("Decal Stay Multiplier:");
	DecalLength.SetNumericOnly(False);
	DecalLength.EditBoxWidth = 32;

	// Decal Count
	DecalCountBox = UWindowEditControl(CreateWindow(class'UWindowEditControl', 10, 100, 180, 150));
	DecalCountBox.Align = TA_Left;
	DecalCountBox.SetText("Current Level Decal Count: ");
	DecalCountBox.SetValue(Right(string(DecalCount), 16));
	DecalCountBox.SetNumericOnly(False);
	DecalCountBox.EditBoxWidth = 48;

	// Max Decals
	MaxDecalsBox = UWindowEditControl(CreateWindow(class'UWindowEditControl', 10, 130, 180, 150));
	MaxDecalsBox.Align = TA_Left;
	MaxDecalsBox.SetText("Maximum Decals: ");
	MaxDecalsBox.SetValue(Right(string(MaxDecals), 16));
	MaxDecalsBox.SetNumericOnly(False);
	MaxDecalsBox.EditBoxWidth = 32;

	// Update button -- not a close button because we need to do some special stuff when
	// closing via this button (ie, save configuration settings..).
	CloseButton = UWindowSmallButton(CreateWindow(class'UWindowSmallButton', 20 , 160, 48, 16));
	CloseButton.SetText("Update");
	CloseButton.NotifyWindow = Self;

	// Cancel button
	CancelButton = UWindowSmallCloseButton(CreateWindow(class'UWindowSmallCloseButton', 80, 160, 48, 16));
	CancelButton.SetText("Cancel");

	// Destroy All button
	ZapButton = UWindowSmallButton(CreateWindow(class'UWindowSmallButton', 140, 160, 48, 16));
	ZapButton.SetText("Clear");
	ZapButton.NotifyWindow = Self;
}

function Notify( UWindowDialogControl C, byte E )
{
	Super.Notify( C, E );

	switch(E)
	{
		case DE_Change:
			switch(C)
			{
				case EnabledCheckbox: UpdateCnt();
				case PermanentCheckbox:
				case DecalLength:
					SaveValues();
					break;
			}
		case DE_Click:
			switch(C)
			{
				case ZapButton:
					ZapDecals();
					UpdateCnt();
					break;

				case CloseButton:
					SaveValues();
					SaveConfig();
					log("DecalStayPlus Enabled:"@bExtendedDecals$" - Permanent:"@bPermanentDecals$" - MaxDecals:"@MaxDecals$" - TimeMultiplier:"@TimeMultiplier);
					ParentWindow.Close();
					break;
			}
	}
}

function SaveValues()
{
	bExtendedDecals = EnabledCheckBox.bChecked;
	bPermanentDecals = PermanentCheckBox.bChecked;
	TimeMultiplier = int(DecalLength.GetValue());
	MaxDecals = int(MaxDecalsBox.GetValue());
	DecalLength.SetText("Decal Stay Multiplier");
	if (!bExtendedDecals)
	{
		PermanentCheckBox.bDisabled = true;
		DecalLength.SetText("DecalStayPlus Disabled");
	} else
		{
			PermanentCheckBox.bDisabled = false;			
			if (bPermanentDecals)
			{
				DecalLength.SetText("Decals stay forever");
			} else
				{
					DecalLength.SetText("Decal Stay Multiplier:");
				}
		}
}

function ZapDecals()
{
	local Scorch S;

	foreach getLevel().allactors(class'Scorch',S)
	{
		S.Destroy();
	}
}

function UpdateCnt()
{
	local Scorch S;

	DecalCount = 0;

	foreach getLevel().allactors(class'Scorch', S)
	{
		DecalCount++;
	}
	if (DecalCountBox != None) DecalCountBox.SetValue(Right(string(DecalCount), 16));


}
defaultproperties
{
     bExtendedDecals=True
     TimeMultiplier=60
     MaxDecals=1000
}
